@@ -101,7 +101,7 @@ bool KCMShell::isRunning()
         return false; // We are the one and only.
     }
 
-    qDebug() << "kcmshell5 with modules '" << m_serviceName << "' is already running.";
+    qDebug() << "kcmshell5 with modules" << m_serviceName << "is already running.";
 
     QDBusInterface iface(m_serviceName, QStringLiteral("/KCModule/dialog"), QStringLiteral("org.kde.KCMShellMultiDialog"));
     QDBusReply<void> reply = iface.call(QStringLiteral("activate"), KStartupInfo::startupId());
@@ -161,7 +161,7 @@ void KCMShell::appExit(const QString &appId, const QString &oldName, const QStri
     Q_UNUSED(newName);
 
     if (!oldName.isEmpty()) {
-        qDebug() << "'" << appId << "' closed, quitting.";
+        qDebug() << appId << "closed, quitting.";
         qApp->quit();
     }
 }
@@ -267,10 +267,14 @@ int main(int _argc, char *_argv[])
             // Look in the namespaces for systemsettings/kinfocenter
             const static auto knownKCMs = findKCMsMetaData();
             const QStringList possibleIds{arg, QStringLiteral("kcm_") + arg, QStringLiteral("kcm") + arg};
-            bool foundKCM = std::any_of(knownKCMs.begin(), knownKCMs.end(), [&possibleIds, &metaDataList](const KPluginMetaData &data) {
+            bool foundKCM = std::any_of(knownKCMs.begin(), knownKCMs.end(), [&possibleIds, &metaDataList, &arg, &serviceName](const KPluginMetaData &data) {
                 bool idMatches = possibleIds.contains(data.pluginId());
                 if (idMatches) {
                     metaDataList << data;
+                    if (!serviceName.isEmpty()) {
+                        serviceName += QLatin1Char('_');
+                    }
+                    serviceName += arg;
                 }
                 return idMatches;
             });
